# gozerbot/admin.py
#
#

""" gozerbot admin related funtions. """


from simplejson import loads

try:
    cmndtable = loads(open('gozerdata' + os.sep + 'run' + os.sep + 'cmndtable').read())
except:
    cmndtable = {}

try:
    pluginlist = loads(open('gozerdata' + os.sep + 'run' + os.sep + 'pluginlist').read())
except:
    pluginlist = []

